/***********************************************************************************************************************
* File Name    : sbrk.c
* Device(s)    : RX
* H/W Platform : GR-SAKURA (RX63N)
* Description  : Configures the MCU heap memory.  The size of the heap is defined by the macro HEAPSIZE below.
***********************************************************************************************************************/
/***********************************************************************************************************************
* History : DD.MM.YYYY Version  Description
*         : 10.07.2017 1.00     First Release
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes   <System Includes> , "Project Includes"
***********************************************************************************************************************/
#include "r_bsp_config.h"

/* ONly use this file if heap is enabled in r_bsp_config. */
#if (BSP_CFG_HEAP_BYTES > 0)

/* Used for getting BSP_CFG_HEAP_BYTES macro. */
#include "platform.h"

/* BCH - 01/16/2013 */
/* 3447: External linkage is not needed for these toolchain supplied library functions.    
   3227: Not going to add const since this is toolchain library function.
   3218: Not going to change since this is provided toolchain library code. 
   3210: Not going to change since this is provided toolchain library code. */
/* PRQA S 3447, 3227, 3218, 3210 ++ */

/***********************************************************************************************************************
Macro definitions
***********************************************************************************************************************/

/***********************************************************************************************************************
Function Prototypes
***********************************************************************************************************************/
/* Memory allocation function prototype declaration */
int8_t  *sbrk(size_t size);

/***********************************************************************************************************************
Global Variables
***********************************************************************************************************************/
//const size_t _sbrk_size=      /* Specifies the minimum unit of */
/* the defined heap area */
extern int8_t *_s1ptr;

union HEAP_TYPE
{
    int32_t  dummy;             /* Dummy for 4-byte boundary */
    int8_t heap[BSP_CFG_HEAP_BYTES];    /* Declaration of the area managed by sbrk*/
};
/* Declare memory heap area */
static union HEAP_TYPE heap_area;
/* End address allocated by sbrk    */
static int8_t *brk=(int8_t *)&heap_area;

/***********************************************************************************************************************
* Function name: sbrk
* Description  : This function configures MCU memory area allocation.
* Arguments    : size - 
*                    assigned area size
* Return value : Start address of allocated area (pass)
*                -1 (failure)
***********************************************************************************************************************/
int8_t  *sbrk(size_t size)                      
{
    int8_t  *p;

    if ((brk + size) > (heap_area.heap + BSP_CFG_HEAP_BYTES))
    {
        /* Empty area size  */
        p = (int8_t *)-1;
    }
    else
    {
        /* Area assignment */
        p = brk;  

        /* End address update */                           
        brk += size;                           
    }

    /* Return result */
    return p;
}

#endif /* BSP_CFG_HEAP_BYTES */




